@@ -108,6 +108,7 @@ SIM401 = (
     "instead of an if-block"
 )
 SIM901 = "SIM901 Use '{better}' instead of '{current}'"
+SIM904 = "SIM904 Initialize dictionary '{dict_name}' directly"
 
 # ast.Constant in Python 3.8, ast.NameConstant in Python 3.6 and 3.7
 BOOL_CONST_TYPES = (ast.Constant, ast.NameConstant)
@@ -612,6 +613,8 @@ def _get_sim110_sim111(node: ast.For) -> List[Tuple[int, int, str]]:
         return errors
     if not hasattr(node.body[0].body[0].value, "value"):
         return errors
+    if isinstance(node.next_sibling, ast.Raise):  # type: ignore
+        return errors
     check = to_source(node.body[0].test)
     target = to_source(node.target)
     iterable = to_source(node.iter)
@@ -1202,7 +1205,15 @@ def is_stmt_equal(a: ast.stmt, b: ast.stmt) -> bool:
     if type(a) is not type(b):
         return False
     if isinstance(a, ast.AST):
-        specials = ("lineno", "col_offset", "ctx", "end_lineno", "parent")
+        specials = (
+            "lineno",
+            "col_offset",
+            "ctx",
+            "end_lineno",
+            "parent",
+            "previous_sibling",
+            "next_sibling",
+        )
         for k, v in vars(a).items():
             if k.startswith("_") or k in specials:
                 continue
@@ -1828,10 +1839,71 @@ def _get_sim901(node: ast.Call) -> List[Tuple[int, int, str]]:
     return errors
 
 
+def _get_sim904(node: ast.Assign) -> List[Tuple[int, int, str]]:
+    """
+    Assign values to dictionary directly at initialization.
+
+    Example
+    -------
+    Code:
+        # Bad
+        a = { }
+        a['b] = 'c'
+
+        # Good
+        a = {'b': 'c'}
+    Bad AST:
+        [
+            Assign(
+                targets=[Name(id='a', ctx=Store())],
+                value=Dict(keys=[], values=[]),
+                type_comment=None,
+            ),
+            Assign(
+                targets=[
+                    Subscript(
+                        value=Name(id='a', ctx=Load()),
+                        slice=Constant(value='b', kind=None),
+                        ctx=Store(),
+                    ),
+                ],
+                value=Constant(value='c', kind=None),
+                type_comment=None,
+            ),
+        ]
+    """
+    errors: List[Tuple[int, int, str]] = []
+    n2 = node.next_sibling  # type: ignore
+    if not (
+        isinstance(node.value, ast.Dict)
+        and isinstance(n2, ast.Assign)
+        and len(n2.targets) == 1
+        and len(node.targets) == 1
+        and isinstance(n2.targets[0], ast.Subscript)
+        and isinstance(n2.targets[0].value, ast.Name)
+        and isinstance(node.targets[0], ast.Name)
+        and n2.targets[0].value.id == node.targets[0].id
+    ):
+        return errors
+    dict_name = to_source(node.targets[0])
+    errors.append(
+        (
+            node.lineno,
+            node.col_offset,
+            SIM904.format(dict_name=dict_name),
+        )
+    )
+    return errors
+
+
 class Visitor(ast.NodeVisitor):
     def __init__(self) -> None:
         self.errors: List[Tuple[int, int, str]] = []
 
+    def visit_Assign(self, node: ast.Assign) -> Any:
+        self.errors += _get_sim904(node)
+        self.generic_visit(node)
+
     def visit_Call(self, node: ast.Call) -> Any:
         self.errors += _get_sim115(Call(node))
         self.errors += _get_sim901(node)
@@ -1915,10 +1987,23 @@ class Plugin:
         visitor = Visitor()
 
         # Add parent
-        for node in ast.walk(self._tree):
-            for child in ast.iter_child_nodes(node):
-                child.parent = node  # type: ignore
+        add_meta(self._tree)
         visitor.visit(self._tree)
 
         for line, col, msg in visitor.errors:
             yield line, col, msg, type(self)
+
+
+def add_meta(root: ast.AST, level: int = 0) -> None:
+    previous_sibling = None
+    for node in ast.iter_child_nodes(root):
+        if level == 0:
+            node.parent = None  # type: ignore
+        node.previous_sibling = previous_sibling  # type: ignore
+        node.next_sibling = None  # type: ignore
+        if previous_sibling:
+            node.previous_sibling.next_sibling = node  # type: ignore
+        previous_sibling = node
+        for child in ast.iter_child_nodes(node):
+            child.parent = node  # type: ignore
+        add_meta(node, level=level + 1)
